.. include:: ../README.rst

Sub-command Detail
------------------

catalog
~~~~~~~
.. program-output:: hspfbintoolbox catalog --help

extract
~~~~~~~
.. program-output:: hspfbintoolbox extract --help
